.. _tutorials:

**********
Tutorials
**********

In this section we present several tutorials on using sigc.

Basic sigc analysis
======================

**Running sigc step by step**

.. toctree::
    :hidden:
    :maxdepth: 4
    
    sigc_main.ipynb
    seurat2scanpy.ipynb
    h5ad_ID2symbol.ipynb
    custom_signatures.ipynb
